@@ -1,6 +1,22 @@
+/* Path conversion for Windows pathnames.
+Copyright (C) 1996-2016 Free Software Foundation, Inc.
+This file is part of GNU Make.
+
+GNU Make is free software; you can redistribute it and/or modify it under the
+terms of the GNU General Public License as published by the Free Software
+Foundation; either version 3 of the License, or (at your option) any later
+version.
+
+GNU Make is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program.  If not, see <http://www.gnu.org/licenses/>.  */
+
+#include "makeint.h"
 #include <string.h>
 #include <stdlib.h>
-#include "make.h"
 #include "pathstuff.h"
 
 /*
@@ -11,15 +27,15 @@ convert_vpath_to_windows32(char *Path, char to_delim)
 {
     char *etok;            /* token separator for old Path */
 
-	/*
-	 * Convert all spaces to delimiters. Note that pathnames which
-	 * contain blanks get trounced here. Use 8.3 format as a workaround.
-	 */
-	for (etok = Path; etok && *etok; etok++)
-		if (isblank ((unsigned char) *etok))
-			*etok = to_delim;
+        /*
+         * Convert all spaces to delimiters. Note that pathnames which
+         * contain blanks get trounced here. Use 8.3 format as a workaround.
+         */
+        for (etok = Path; etok && *etok; etok++)
+                if (isblank ((unsigned char) *etok))
+                        *etok = to_delim;
 
-	return (convert_Path_to_windows32(Path, to_delim));
+        return (convert_Path_to_windows32(Path, to_delim));
 }
 
 /*
@@ -32,6 +48,9 @@ convert_Path_to_windows32(char *Path, char to_delim)
     char *p;            /* points to element of old Path */
 
     /* is this a multi-element Path ? */
+    /* FIXME: Perhaps use ":;\"" in strpbrk to convert all quotes to
+       delimiters as well, as a way to handle quoted directories in
+       PATH?  */
     for (p = Path, etok = strpbrk(p, ":;");
          etok;
          etok = strpbrk(p, ":;"))
@@ -53,11 +72,20 @@ convert_Path_to_windows32(char *Path, char to_delim)
             } else
                 /* all finished, force abort */
                 p += strlen(p);
+        } else if (*p == '"') { /* a quoted directory */
+            for (p++; *p && *p != '"'; p++) /* skip quoted part */
+                ;
+            etok = strpbrk(p, ":;");        /* find next delimiter */
+            if (etok) {
+                *etok = to_delim;
+                p = ++etok;
+            } else
+                p += strlen(p);
         } else {
             /* found another one, no drive letter */
             *etok = to_delim;
             p = ++etok;
-	}
+        }
 
     return Path;
 }
@@ -66,7 +94,7 @@ convert_Path_to_windows32(char *Path, char to_delim)
  * Convert to forward slashes. Resolve to full pathname optionally
  */
 char *
-w32ify(char *filename, int resolve)
+w32ify(const char *filename, int resolve)
 {
     static char w32_path[FILENAME_MAX];
     char *p;
@@ -86,14 +114,14 @@ w32ify(char *filename, int resolve)
 char *
 getcwd_fs(char* buf, int len)
 {
-	char *p;
+        char *p = getcwd(buf, len);
 
-	if (p = getcwd(buf, len)) {
-		char *q = w32ify(buf, 0);
-		strncpy(buf, q, len);
-	}
+        if (p) {
+                char *q = w32ify(buf, 0);
+                strncpy(buf, q, len);
+        }
 
-	return p;
+        return p;
 }
 
 #ifdef unused
